Contributing to ZTPServer
=========================
Arista EOS+ ZTPServer provides a community based implementation of a bootstrap solution for working with Arista EOS switches.   This document provides different options for contributing to this project.

Contributing Code
=================
Arista EOS+ ZTPServer provides all of its source available to anyone on Github at github.com/arista-eosplus/ztpserver.   The project is freely available to anyone to fork and use in their own implementations.  The Arista EOS+ community gladly accepts pull requests that add new features, enhance existing features or fix bugs.  

All contributed code should be done using pull requests.  Once a pull request is initiated, a member of the Arista EOS+ community will review the code and either accept it as is or provide feedback on things to change.  

As a procedural note, all pull requests that add new features and/or enhance the operation of ZTPServer are expected to have corresponding test cases with them.  Pull requests will be not accepted without them.

Feature Requests
================
Another available way to contribute to this project is to provide requests for features.  Feature requests should be submitted through Github issues for this project and tagged as enhancement and server or client or action.  All enhancement requests are included as part of the planning process and will be considered for implementation

Bugs
====
If you happen to find a bug with ZTPServer, please open an issue and flag it as a bug.  In the issue description please provide details about what you were trying to do, any errors and/or tracebacks and any other information necessary to replicate the bug.  

Contact
=======
If you have any additional questions about ZTPServer please send an email to eosplus-dev@arista.com
